@@ -33,6 +33,10 @@ use std::{mem, slice, str};
 #[derive(Debug)]
 pub struct AggregateIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for AggregateIterator {}
+
 impl Drop for AggregateIterator {
     fn drop(&mut self) { unsafe { cass_iterator_free(self.0) } }
 }
@@ -56,6 +60,10 @@ impl Iterator for AggregateIterator {
 #[derive(Debug)]
 pub struct UserTypeIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for UserTypeIterator {}
+
 impl Drop for UserTypeIterator {
     fn drop(&mut self) { unsafe { cass_iterator_free(self.0) } }
 }
@@ -84,6 +92,10 @@ impl UserTypeIterator {
 #[derive(Debug)]
 pub struct FunctionIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for FunctionIterator {}
+
 impl Iterator for FunctionIterator {
     type Item = FunctionMeta;
     fn next(&mut self) -> Option<<Self as Iterator>::Item> {
@@ -101,6 +113,10 @@ impl Iterator for FunctionIterator {
 #[derive(Debug)]
 pub struct TableIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for TableIterator {}
+
 impl Iterator for TableIterator {
     type Item = TableMeta;
     fn next(&mut self) -> Option<<Self as Iterator>::Item> {
@@ -117,6 +133,10 @@ impl Iterator for TableIterator {
 #[derive(Debug)]
 pub struct KeyspaceIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for KeyspaceIterator {}
+
 impl Iterator for KeyspaceIterator {
     type Item = KeyspaceMeta;
     fn next(&mut self) -> Option<<Self as Iterator>::Item> {
@@ -133,6 +153,10 @@ impl Iterator for KeyspaceIterator {
 #[derive(Debug)]
 pub struct ColumnIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for ColumnIterator {}
+
 impl Iterator for ColumnIterator {
     type Item = ColumnMeta;
     fn next(&mut self) -> Option<<Self as Iterator>::Item> {
@@ -149,6 +173,10 @@ impl Iterator for ColumnIterator {
 #[derive(Debug)]
 pub struct FieldIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for FieldIterator {}
+
 impl Iterator for FieldIterator {
     type Item = Field;
     #[allow(cast_possible_truncation)]
@@ -239,6 +267,10 @@ impl Protected<*mut _CassIterator> for SetIterator {
 #[derive(Debug)]
 pub struct SetIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for SetIterator {}
+
 // impl<'a> Display for &'a SetIterator {
 //    fn fmt(&self, f:&mut Formatter) -> fmt::Result {
 //        for item in self {
@@ -274,6 +306,10 @@ impl SetIterator {
 #[derive(Debug)]
 pub struct MapIterator(*mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for MapIterator {}
+
 impl MapIterator {
     fn get_key(&mut self) -> Value { unsafe { Value::build(cass_iterator_get_map_key(self.0)) } }
     fn get_value(&mut self) -> Value { unsafe { Value::build(cass_iterator_get_map_value(self.0)) } }
@@ -286,6 +322,10 @@ impl MapIterator {
 #[derive(Debug)]
 pub struct TupleIterator(pub *mut _CassIterator);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for TupleIterator {}
+
 impl Drop for TupleIterator {
     fn drop(&mut self) { unsafe { cass_iterator_free(self.0) } }
 }
@@ -323,3 +363,4 @@ impl Iterator for MapIterator {
         }
     }
 }
+
