@@ -101,6 +101,7 @@ pub enum ValueType {
     TIME,
     SMALL_INT,
     TINY_INT,
+    DURATION,
     LIST,
     MAP,
     SET,
@@ -131,6 +132,7 @@ enhance_nullary_enum!(ValueType, CassValueType_, {
     (TIME, CASS_VALUE_TYPE_TIME, "TIME"),
     (SMALL_INT, CASS_VALUE_TYPE_SMALL_INT, "SMALL_INT"),
     (TINY_INT, CASS_VALUE_TYPE_TINY_INT, "TINY_INT"),
+    (DURATION, CASS_VALUE_TYPE_DURATION, "DURATION"),
     (LIST, CASS_VALUE_TYPE_LIST, "LIST"),
     (MAP, CASS_VALUE_TYPE_MAP, "MAP"),
     (SET, CASS_VALUE_TYPE_SET, "SET"),
@@ -211,6 +213,7 @@ impl Debug for Value {
                 ValueType::INT => write_value(f, self.get_i32(), |f, v| write!(f, "{:?}", v)),
                 ValueType::SMALL_INT => write_value(f, self.get_i16(), |f, v| write!(f, "{:?}", v)),
                 ValueType::TINY_INT => write_value(f, self.get_i8(), |f, v| write!(f, "{:?}", v)),
+                ValueType::DURATION => write_value(f, self.get_i32(), |f, v| write!(f, "{:?}", v)),
                 ValueType::INET => write_value(f, self.get_inet(), |f, v| write!(f, "{:?}", v)),
                 ValueType::TIMESTAMP => write_value(f, self.get_i64(), |f, v| write!(f, "{:?}", v)),
                 ValueType::TIMEUUID => write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID: {}", v)),
@@ -249,6 +252,7 @@ impl Display for Value {
                 ValueType::INT => write_value(f, self.get_i32(), |f, v| write!(f, "{}", v)),
                 ValueType::SMALL_INT => write_value(f, self.get_i16(), |f, v| write!(f, "{}", v)),
                 ValueType::TINY_INT => write_value(f, self.get_i8(), |f, v| write!(f, "{}", v)),
+                ValueType::DURATION => write_value(f, self.get_i32(), |f, v| write!(f, "{:?}", v)),
                 ValueType::INET => write_value(f, self.get_inet(), |f, v| write!(f, "INET:{:?}", v)),
                 ValueType::TIMESTAMP => write_value(f, self.get_i64(), |f, v| write!(f, "{}", v)),
                 ValueType::TIMEUUID => write_value(f, self.get_uuid(), |f, v| write!(f, "TIMEUUID:{}", v)),
